@@ -1,9 +1,8 @@
-use strict;
-use warnings;
 package Net::SAML2::Protocol::Assertion;
-our $VERSION = '0.62'; # VERSION
-
 use Moose;
+
+our $VERSION = '0.64'; # VERSION
+
 use MooseX::Types::DateTime qw/ DateTime /;
 use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
 use DateTime;
@@ -13,6 +12,8 @@ use Net::SAML2::XML::Util qw/ no_comments /;
 use Net::SAML2::XML::Sig;
 use XML::Enc;
 use XML::LibXML;
+use List::Util qw(first);
+use URN::OASIS::SAML2 qw(STATUS_SUCCESS);
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
@@ -26,12 +27,14 @@ has 'not_before' => (isa => DateTime,          is => 'ro', required => 1);
 has 'session'         => (isa => 'Str', is => 'ro', required => 1);
 has 'in_response_to'  => (isa => 'Str', is => 'ro', required => 1);
 has 'response_status' => (isa => 'Str', is => 'ro', required => 1);
+has 'response_substatus' => (isa => 'Str', is => 'ro');
 has 'xpath' => (isa => 'XML::LibXML::XPathContext', is => 'ro', required => 1);
 has 'nameid_object' => (
-    isa      => 'XML::LibXML::Element',
-    is       => 'ro',
-    required => 1,
-    init_arg => 'nameid'
+    isa       => 'XML::LibXML::Element',
+    is        => 'ro',
+    required  => 0,
+    init_arg  => 'nameid',
+    predicate => 'has_nameid',
 );
 
 
@@ -96,36 +99,63 @@ sub new_from_xml {
         $attributes->{$node->getAttribute('Name')} = [map $_->string_value, @values];
     }
 
+    my $xpath_base = '//samlp:Response/saml:Assertion/saml:Conditions/';
+
     my $not_before;
-    if($xpath->findvalue('//saml:Conditions/@NotBefore')) {
-        $not_before = DateTime::Format::XSD->parse_datetime(
-            $xpath->findvalue('//saml:Conditions/@NotBefore'));
+    if (my $value = $xpath->findvalue($xpath_base . '@NotBefore')) {
+        $not_before = DateTime::Format::XSD->parse_datetime($value);
+    }
+    elsif (my $global = $xpath->findvalue('//saml:Conditions/@NotBefore')) {
+        $not_before = DateTime::Format::XSD->parse_datetime($global);
     }
     else {
         $not_before = DateTime::HiRes->now();
     }
 
     my $not_after;
-    if($xpath->findvalue('//saml:Conditions/@NotOnOrAfter')) {
-        $not_after = DateTime::Format::XSD->parse_datetime(
-            $xpath->findvalue('//saml:Conditions/@NotOnOrAfter'));
+    if (my $value = $xpath->findvalue($xpath_base . '@NotOnOrAfter')) {
+        $not_after = DateTime::Format::XSD->parse_datetime($value);
+    }
+    elsif (my $global = $xpath->findvalue('//saml:Conditions/@NotOnOrAfter')) {
+        $not_after = DateTime::Format::XSD->parse_datetime($global);
     }
     else {
         $not_after = DateTime->from_epoch(epoch => time() + 1000);
     }
 
+    my $nameid;
+    if (my $node = $xpath->findnodes('//samlp:Response/saml:Assertion/saml:Subject/    saml:NameID')) {
+        $nameid = $node->get_node(1);
+    }
+    elsif (my $global = $xpath->findnodes('//saml:Subject/saml:NameID')) {
+        $nameid = $global->get_node(1);
+    }
+
+    my $nodeset = $xpath->findnodes('/samlp:Response/samlp:Status/samlp:StatusCode');
+    croak("Unable to parse status from assertion") unless ($nodeset->size);
+
+    my $status_node = $nodeset->get_node(1);
+    my $status = $status_node->getAttribute('Value');
+    my $sub_status;
+
+    if (my $s = first { $_->isa('XML::LibXML::Element') } $status_node->childNodes) {
+        $sub_status = $s->getAttribute('Value');
+    }
+
     my $self = $class->new(
+        id             => $xpath->findvalue('//saml:Assertion/@ID'),
         issuer         => $xpath->findvalue('//saml:Assertion/saml:Issuer'),
         destination    => $xpath->findvalue('/samlp:Response/@Destination'),
         attributes     => $attributes,
         session        => $xpath->findvalue('//saml:AuthnStatement/@SessionIndex'),
-        nameid         => $xpath->findnodes('//saml:Subject/saml:NameID')->get_node(1),
+        $nameid ? (nameid => $nameid) : (),
         audience       => $xpath->findvalue('//saml:Conditions/saml:AudienceRestriction/saml:Audience'),
         not_before     => $not_before,
         not_after      => $not_after,
         xpath          => $xpath,
         in_response_to => $xpath->findvalue('//saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/@InResponseTo'),
-        response_status => $xpath->findvalue('//samlp:Response/samlp:Status/samlp:StatusCode/@Value'),
+        response_status => $status,
+        $sub_status ? (response_substatus => $sub_status) : (),
     );
 
     return $self;
@@ -133,23 +163,46 @@ sub new_from_xml {
 
 
 sub name {
-    my($self) = @_;
-    return $self->attributes->{CN}->[0];
+    my $self = shift;
+    return $self->attributes->{CN}[0];
 }
 
 
 sub nameid {
     my $self = shift;
+    return unless $self->has_nameid;
     return $self->nameid_object->textContent;
 }
 
 
 sub nameid_format {
     my $self = shift;
+    return unless $self->has_nameid;
     return $self->nameid_object->getAttribute('Format');
 }
 
 
+sub nameid_name_qualifier {
+    my $self = shift;
+    return unless $self->has_nameid;
+    return $self->nameid_object->getAttribute('NameQualifier');
+}
+
+
+sub nameid_sp_name_qualifier {
+    my $self = shift;
+    return unless $self->has_nameid;
+    return $self->nameid_object->getAttribute('SPNameQualifier');
+}
+
+
+sub nameid_sp_provided_id {
+    my $self = shift;
+    return unless $self->has_nameid;
+    return $self->nameid_object->getAttribute('SPProvidedID');
+}
+
+
 sub valid {
     my ($self, $audience, $in_response_to) = @_;
 
@@ -169,6 +222,13 @@ sub valid {
     return 1;
 }
 
+
+sub success {
+    my $self = shift;
+    return 1 if $self->response_status eq STATUS_SUCCESS;
+    return 0;
+}
+
 1;
 
 __END__
@@ -183,7 +243,7 @@ Net::SAML2::Protocol::Assertion - Net::SAML2::Protocol::Assertion - SAML2 assert
 
 =head1 VERSION
 
-version 0.62
+version 0.64
 
 =head1 SYNOPSIS
 
@@ -228,7 +288,17 @@ EncryptedAssertion is properly validated.
 
 =back
 
-=head2 name( )
+=head2 response_status
+
+Returns the response status
+
+=head2 response_substatus
+
+SAML errors are usually "nested" ("Responder -> RequestDenied" for instance,
+means that the responder in this transaction (the IdP) denied the login
+request). For proper error message generation, both levels are needed.
+
+=head2 name
 
 Returns the CN attribute, if provided.
 
@@ -240,6 +310,18 @@ Returns the NameID
 
 Returns the NameID Format
 
+=head2 nameid_name_qualifier
+
+Returns the NameID NameQualifier
+
+=head2 nameid_sp_name_qualifier
+
+Returns the NameID SPNameQualifier
+
+=head2 nameid_sp_provided_id
+
+Returns the NameID SPProvidedID
+
 =head2 valid( $audience, $in_response_to )
 
 Returns true if this Assertion is currently valid for the given audience.
@@ -251,13 +333,28 @@ that the assertion that was received was for the request that was made.
 Checks the audience matches, and that the current time is within the
 Assertions validity period as specified in its Conditions element.
 
-=head1 AUTHOR
+=head2 success
+
+Returns true if the response status is a success, returns false otherwise.
+In case the assertion isn't successfull, the L</response_status> and L</response_substatus> calls can be use to see why the assertion wasn't successful.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Chris Andrews  <chrisa@cpan.org>
 
+=item *
+
+Timothy Legge <timlegge@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Chris Andrews and Others, see the git log.
+This software is copyright (c) 2023 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
