@@ -8,7 +8,7 @@
 use strict;
 use warnings;
 package Net::SAML2::XML::Sig; use base qw(XML::Sig);
-our $VERSION = '0.62'; #VERSION
+our $VERSION = '0.64'; #VERSION
 #
 # ABSTRACT: Net::SAML2 subclass of XML::Sig
 
@@ -26,15 +26,25 @@ Net::SAML2::XML::Sig - Net::SAML2 subclass of XML::Sig
 
 =head1 VERSION
 
-version 0.62
+version 0.64
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Chris Andrews  <chrisa@cpan.org>
 
+=item *
+
+Timothy Legge <timlegge@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Chris Andrews and Others, see the git log.
+This software is copyright (c) 2023 by Venda Ltd, see the CONTRIBUTORS file for others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
